@@ -89,7 +89,7 @@ MODEL_CONFIGS = [
     ModelConfig(
         short_name="MidJourney-PaperCut",
         config_path="configs/stable-diffusion-v1.yaml",
-        weights_url="https://huggingface.co/ShadoWxShinigamI/MidJourney-PaperCut/blob/main/Mdjrny-pprct_step_7000.ckpt",
+        weights_url="https://huggingface.co/ShadoWxShinigamI/MidJourney-PaperCut/resolve/main/Mdjrny-pprct_step_7000.ckpt",
         default_image_size=512,
     ),
     ModelConfig(
@@ -131,7 +131,7 @@ MODEL_CONFIGS = [
     ModelConfig(
         short_name="ModernDisney",
         config_path="configs/stable-diffusion-v1.yaml",
-        weights_url="https://huggingface.co/nitrosocke/mo-di-diffusion/blob/main/moDi-v1-pruned.ckpt",
+        weights_url="https://huggingface.co/nitrosocke/mo-di-diffusion/resolve/main/moDi-v1-pruned.ckpt",
         default_image_size=512,
     ),
     ModelConfig(
